/*
 * JProgressBarBeanInfoSwingBeanInfo.template	1.4 98/04/13
 * 
 * Copyright (c) 1997 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * This software is the confidential and proprietary information of Sun
 * Microsystems, Inc. ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Sun.
 * 
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF THE
 * SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR ANY DAMAGES
 * SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING
 * THIS SOFTWARE OR ITS DERIVATIVES.
 * 
 */

package com.sun.java.swing;

import com.sun.java.swing.beaninfo.SwingBeanInfo;

import java.beans.BeanDescriptor;
import java.beans.PropertyDescriptor;
import java.awt.Image;


/**
 * Descriptive information about the JProgressBar class for Java 
 * Beans application builders.  This BeanInfo class provides descriptions
 * of each property, of the bean itself, it indicates which
 * JProgressBar properties are bound, and it provides other
 * information and icons useful to builders.
 * 
 * @version 1.4 04/13/98
 * @author <your name here>
 */

public class JProgressBarBeanInfo extends SwingBeanInfo 
{
    private static final Class classJProgressBar = com.sun.java.swing.JProgressBar.class;

    /**
     * @return a JProgressBar BeanDescriptor
     */
    public BeanDescriptor getBeanDescriptor() {
	return createBeanDescriptor(classJProgressBar, new Object[] {
				PREFERRED, Boolean.TRUE,
				              "isContainer",Boolean.FALSE,
     
			        SHORTDESCRIPTION, "A component that displays an integer value graphically."
	    }			    
        );            	       		    
    }


    /**
     * Create a JProgressBar PropertyDescriptor.  This is just an internal
     * convenience method that allows one to leave the JProgressBar.class
     * argument out of the createPropertyDescriptor() class in the 
     * getPropertyDescriptors() method below.
     * 
     * @param name the name of the property
     * @param args an array java.beans.PropertyDescriptor property names and values
     * @return a JProgressBar PropertyDescriptor.
     * @see SwingBeanInfo#createPropertyDescriptor
     */
    private PropertyDescriptor createPropertyDescriptor(String name, Object[] args) {
	return super.createPropertyDescriptor(classJProgressBar, name, args);
    }


    /**
     * This method returns a list of bean PropertyDescriptors, one for each public
     * property in JProgressBar.  The first property is the "default" property.
     *
     * @return a complete list of bean PropertyDescriptors for JProgressBar
     * @see SwingBeanInfo
     * @see java.beans.BeanInfo#getDefaultPropertyIndex
     */
    public PropertyDescriptor[] getPropertyDescriptors() 
    {
         
	return new PropertyDescriptor[] {
            
             createPropertyDescriptor("UIClassID", new Object[] {
                           EXPERT, Boolean.TRUE,
                 SHORTDESCRIPTION, "A string that specifies the name of the L&F class.",
               }
             ),
             
             createPropertyDescriptor("accessibleContext", new Object[] {
                           EXPERT, Boolean.TRUE,
                 SHORTDESCRIPTION, "The AccessibleContext associated with this ProgressBar.",
               }
             ),
             
             createPropertyDescriptor("UI", new Object[] {
                           EXPERT, Boolean.TRUE,
                 SHORTDESCRIPTION, "The ProgressBarUI implementation that defines the combo box look and feel.",
               }
             ),
             
             createPropertyDescriptor("value", new Object[] {
                        PREFERRED, Boolean.TRUE,
                 SHORTDESCRIPTION, "The model's current value.",
               }
             ),
             
             createPropertyDescriptor("orientation", new Object[] {
                        PREFERRED, Boolean.TRUE,
                 SHORTDESCRIPTION, "The progress bar's orientation.",
               }
             ),
             
             createPropertyDescriptor("maximum", new Object[] {
                        PREFERRED, Boolean.TRUE,
                 SHORTDESCRIPTION, "The model's maximum value.",
               }
             ),
             
             createPropertyDescriptor("borderPainted", new Object[] {
                 SHORTDESCRIPTION, "Whether the progress bar should have a border.",
               }
             ),
             
             createPropertyDescriptor("minimum", new Object[] {
                        PREFERRED, Boolean.TRUE,
                 SHORTDESCRIPTION, "The model's minimum value.",
               }
             ),
             
             createPropertyDescriptor("model", new Object[] {
                           EXPERT, Boolean.TRUE,
                 SHORTDESCRIPTION, "The data model used by the JProgressBar.",
               }
             )
             
	};
    }


    /**
     * @return an icon of the specified kind for JProgressBar
     */
    public Image getIcon(int kind) {
	Image i;
	switch (kind){
	  case ICON_COLOR_32x32:
	          i = loadImage("beaninfo/images/JProgressBarColor32.gif");
		  return ((i == null) ? loadImage("beaninfo/images/JComponentColor32.gif") : i);
	  case ICON_COLOR_16x16:
		  i = loadImage("beaninfo/images/JProgressBarColor16.gif");
		  return ((i == null) ? loadImage("beaninfo/images/JComponentColor16.gif") : i);
	  case ICON_MONO_32x32:
		  i = loadImage("beaninfo/images/JProgressBarMono32.gif");
		  return ((i == null) ? loadImage("beaninfo/images/JComponentMono32.gif") : i);		  
	  case ICON_MONO_16x16:
		  i = loadImage("beaninfo/images/JProgressBarMono16.gif");
		  return ((i == null) ? loadImage("beaninfo/images/JComponentMono16.gif") : i);		  
	  default:
	    return super.getIcon(kind);
	}
    }
}


